@@ -27,16 +27,19 @@ def escape_html(s):
     except AttributeError:
         raise TypeError("expected string or unicode object, "
                         "%s found" % s.__class__.__name__)
+
+
 escape_html_native = escape_html
 
 try:
     from wheezy.html.boost import escape_html
-    html_escape = escape_html
+    html_escape = escape_html  # pragma: nocover
 except ImportError:  # pragma: nocover
     html_escape = escape_html
 
 
-html_id = lambda name: name.replace('_', '-')
+def html_id(name):
+    return name.replace('_', '-')
 
 
 def format_value(value, format_spec=None, format_provider=None):
@@ -84,7 +87,10 @@ def format_value(value, format_spec=None, format_provider=None):
         return format_provider(value, format_spec)
 
 
-str_format_provider = lambda value, format_spec: str_type(value)
+def str_format_provider(value, format_spec):
+    return str_type(value)
+
+
 min_date = date(1900, 1, 1)
 min_datetime = datetime(1900, 1, 1)
 
